# Topsis-Himanshu-101917178

Technique of Order of Preference By Similarity to Ideal solution

You just have to pass 3 arguments
1. data csv file containing more than 3 columns
2. weights list
3. Impacts or criteria list
